From 6e0698293c320e0fb743128dd33baad38671f991 Mon Sep 17 00:00:00 2001
From: pewgeuges <73141620+pewgeuges@users.noreply.github.com>
Date: Thu, 3 Dec 2020 17:38:14 +0000
Subject: [PATCH] upcoming 2.1.4 was not ready, instead thanks for testing
2.1.4d8, to be shared on Forum too
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2431035 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/dashboard/layout.php | 5 +-
class/dashboard/subpage-main.php | 11 +-
class/settings.php | 31 ++--
class/task.php | 134 ++++++++--------
css/public.css | 24 +--
css/settings.css | 27 ++--
footnotes.php | 4 +-
readme.txt | 41 ++---
templates/dashboard/customize-css.html | 52 +++---
.../dashboard/customize-mouse-over-box.html | 130 +++++++--------
.../dashboard/customize-superscript.html | 30 ++--
templates/dashboard/diagnostics.html | 74 ++++-----
templates/dashboard/expert-lookup.html | 72 ++++-----
templates/dashboard/settings-love.html | 24 +--
templates/dashboard/settings-other.html | 26 +--
.../settings-reference-container.html | 150 +++++++++---------
templates/dashboard/settings-styling.html | 46 +++---
.../reference-container-body-combi.html | 2 +-
18 files changed, 439 insertions(+), 444 deletions(-)
diff --git a/class/dashboard/layout.php b/class/dashboard/layout.php
index 68e9a7e..c15f5da 100644
--- a/class/dashboard/layout.php
+++ b/class/dashboard/layout.php
@@ -9,10 +9,11 @@
* Edited:
* 2.1.2 add versioning of settings.css for cache busting 2020-11-19T1456+0100
* 2.1.4 automate passing version number for cache busting 2020-11-30T0648+0100
- * 2.1.4 started fixing punctuation-related localization issue in dashboard labels 2020-12-01T0211+0100
+ * 2.1.4 start fixing punctuation-related localization issue in dashboard labels 2020-12-01T0211+0100
* ########## this fix reverted for now; restore when updating strings and translations
+ * 2.1.4 step argument and support for floating in numbox 2020-12-03T0952+0100
*
- * Last modified: 2020-12-01T1559+0100
+ * Last modified: 2020-12-03T0952+0100
*/
diff --git a/class/dashboard/subpage-main.php b/class/dashboard/subpage-main.php
index e7cdb81..8be5dcd 100644
--- a/class/dashboard/subpage-main.php
+++ b/class/dashboard/subpage-main.php
@@ -7,13 +7,12 @@
* @since 1.5.0 14.09.14 14:47
*
* Edited for:
- * 2.0.4 2020-11-01T0509+0100
- * 2.1.0 2020-11-08T2148+0100
- * 2.1.1 2020-11-16T2152+0100
- * 2.1.3 2020-11-24T0955+0100
- * 2.1.4 2020-11-28T1050+0100
+ * 2.0.4 restore arrow settings 2020-11-01T0509+0100
+ * 2.1.0 read-on button label 2020-11-08T2148+0100
+ * 2.1.1 options for ref container and alternative tooltips 2020-11-16T2152+0100
+ * 2.1.4 settings for ref container and tooltips 2020-12-03T0950+0100
*
- * Last modified: 2020-11-30T0711+0100
+ * Last modified: 2020-12-03T1359+0100
*/
/**
diff --git a/class/settings.php b/class/settings.php
index 3110764..812eed4 100644
--- a/class/settings.php
+++ b/class/settings.php
@@ -7,18 +7,19 @@
* @since 1.5.0 14.09.14 10:43
*
* Edited for:
- * 2.0.4 restore arrow settings 2020-11-02T2115+0100
- * 2.0.7 remove hook the_post 2020-11-06T1342+0100
- * 2.1.0 add read-on button label customization 2020-11-08T2149+0100
- * 2.1.1 fix tooltips on site by alternative 2020-11-11T1819+0100
- * 2.1.1 fix disabling backlink symbol 2020-11-16T2021+0100
- * 2.1.1 fix superscript by making it optional
- * 2.1.1 fix start pages by option to hide ref container
- * 2.1.1 fix ref container by option restoring 3-column layout
- * 2.1.1 fix ref container by option to switch index/symbol 2020-11-16T2022+0100
- * 2.1.3 fix ref container positioning by priority level 2020-11-17T0205+0100
+ * 2.0.4 restore arrow settings 2020-11-02T2115+0100
+ * 2.0.7 remove hook the_post 2020-11-06T1342+0100
+ * 2.1.0 add read-on button label customization 2020-11-08T2149+0100
+ * 2.1.1 fix tooltips on site by alternative 2020-11-11T1819+0100
+ * 2.1.1 fix disabling backlink symbol 2020-11-16T2021+0100
+ * 2.1.1 fix superscript by making it optional
+ * 2.1.1 fix start pages by option to hide ref container
+ * 2.1.1 fix ref container by option restoring 3-column layout
+ * 2.1.1 fix ref container by option to switch index/symbol 2020-11-16T2022+0100
+ * 2.1.3 fix ref container positioning by priority level 2020-11-17T0205+0100
+ * 2.1.4 more settings container keys 2020-12-03T0955+0100
*
- * Last modified: 2020-11-17T0311+0100
+ * Last modified: 2020-12-03T1603+0100
*/
@@ -492,12 +493,12 @@ class MCI_Footnotes_Settings {
self::C_STR_BACKLINKS_TERMINATOR_CUSTOM => '',
// set backlinks column width:
- self::C_BOOL_BACKLINKS_COLUMN_WIDTH_ENABLED => 'yes',
- self::C_INT_BACKLINKS_COLUMN_WIDTH_SCALAR => '2',
- self::C_STR_BACKLINKS_COLUMN_WIDTH_UNIT => 'em',
+ self::C_BOOL_BACKLINKS_COLUMN_WIDTH_ENABLED => 'no',
+ self::C_INT_BACKLINKS_COLUMN_WIDTH_SCALAR => '50',
+ self::C_STR_BACKLINKS_COLUMN_WIDTH_UNIT => 'px',
// set backlinks column max width:
- self::C_BOOL_BACKLINKS_COLUMN_MAX_WIDTH_ENABLED => 'yes',
+ self::C_BOOL_BACKLINKS_COLUMN_MAX_WIDTH_ENABLED => 'no',
self::C_INT_BACKLINKS_COLUMN_MAX_WIDTH_SCALAR => '140',
self::C_STR_BACKLINKS_COLUMN_MAX_WIDTH_UNIT => 'px',
diff --git a/css/public.css b/css/public.css
index 5795296..8442b88 100755
--- a/css/public.css
+++ b/css/public.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.4d7
+ * Version: 2.1.4d8
*
- * Last modified: 2020-12-03T0836+0100
+ * Last modified: 2020-12-03T1834+0100
*/
@@ -261,28 +261,30 @@ when hovered in some themes, not in others:
}
/*
-These rules are moved to settings defaulting to this
-since 2.1.4
-auto-expanding column to fit widest
-Not using 'max-content' as that causes no-wrap and overflows.
+These rules are just defauls preventing the table from filling the width.
+They are not very effective by lack of table-layout: fixed;
+since 2.1.4 settings are optionally available, with table-layout: fixed;
+By default, the backlink column is auto-expanding to fit widest.
+Not using 'max-content' as that causes no-wrap and overflows.
+These are overridden if settings are enabled.
+*/
.footnote_plugin_index,
.footnote_plugin_index_combi {
- max-width: 140px;
- width: 2em;
+ max-width: 100px;
+ width: 2.5em;
}
-*/
-
/*
Responsive
*/
@media only screen and (max-width: 768px) {
.footnote_plugin_index,
.footnote_plugin_index_combi {
- max-width: 100px;
+ max-width: 80px;
}
}
+
/****************************************************************
Footnotes printing style rules
diff --git a/css/settings.css b/css/settings.css
index 4fd6767..6951ae2 100755
--- a/css/settings.css
+++ b/css/settings.css
@@ -4,17 +4,18 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.4d7
+ * Version: 2.1.4d8
*
- * Last modified: 2020-12-03T0837+0100
+ * Last modified: 2020-12-03T1834+0100
*/
-/* MCI Footnotes logo
- *
- * The classes with 'heading' fix display in dashboard
- * See class/config.php and css/public.css
- */
+/*****************************************************
+MCI Footnotes logo
+
+The classes with 'heading' fix display in dashboard
+See class/config.php and css/public.css
+*/
.postbox-header {
position: relative;
@@ -38,7 +39,7 @@
left: 96px;
}
-/*
+/*************************************************************************
On User Request: limited to a number of IDs to not affect all dashboards
*/
@@ -119,7 +120,7 @@ span.footnote_highlight_placeholder {
text-align: center !important;
}
-/*
+/*********************************************************
initialized from style attributes in templates
IE doesn’t support nth child, but these are not critical
*/
@@ -143,6 +144,10 @@ IE doesn’t support nth child, but these are not critical
white-space: nowrap;
}
+#settings-other tr td:nth-child(2) {
+ width: 30%;
+}
+
.footnotes-description {
padding: 0 10%;
}
@@ -150,7 +155,3 @@ IE doesn’t support nth child, but these are not critical
font-size: 1.4em;
font-style: italic;
}
-
-#settings-other tr td:nth-child(2) {
- width: 30%;
-}
diff --git a/footnotes.php b/footnotes.php
index b8ee043..32ba231 100755
--- a/footnotes.php
+++ b/footnotes.php
@@ -4,12 +4,12 @@
Plugin URI: https://wordpress.org/plugins/footnotes/
Description: time to bring footnotes to your website! footnotes are known from offline publishing and everybody takes them for granted when reading a magazine.
Author: Mark Cheret
- Version: 2.1.4d7
+ Version: 2.1.4d8
Author URI: http://cheret.de/plugins/footnotes-2/
Text Domain: footnotes
Domain Path: /languages
*/
-define( 'FOOTNOTES_VERSION', '2.1.4d7' );
+define( 'FOOTNOTES_VERSION', '2.1.4d8' );
/*
Copyright 2020 Mark Cheret (email: mark@cheret.de)
diff --git a/readme.txt b/readme.txt
index d9213c6..9e3913f 100755
--- a/readme.txt
+++ b/readme.txt
@@ -80,37 +80,26 @@ Visit this swift write-up from a **footnotes** user by the name of **Southwest**
== Changelog ==
-= 2.1.4d7 =
-- Bugfix: Reference container: fix layout issues by moving backlink column width to settings
-- Bugfix: Tooltip: fix issues with font size by moving it to settings and defaulting to previous
-
-= 2.1.4d6 =
-- Bugfix: Dashboard: move arrow settings from Customize to Settings > Reference container to reunite and fix issue with new heading wording
-
-= 2.1.4d5
-- Bugfix: Reference container: separating and terminating punctuation optional and customizable
-- Bugfix: Reference container: Label: delete overflow hidden rule
-- Bugfix: WordPress hooks: the_content: set priority to 1000 as a safeguard
+= 2.1.4d8 =
- Bugfix: Dashboard: Main settings: fix layout, raise shortcodes to top
+- Bugfix: Dashboard: move arrow settings from Customize to Settings > Reference container to reunite and fix issue with new heading wording
- Bugfix: Dashboard: Other settings: Excerpt: display guidance next to select box
-
-= 2.1.4d4 =
-- Bugfix: Reference container: Backlinks: disable separators and terminators
-- Bugfix: Reference container: Backlinks: optional line breaks to stack enumerations
-
-= 2.1.4d3 =
+- Bugfix: Layout: Tooltips: prevent line break in Read-on link label
+- Bugfix: Reference container, tooltips: fix line wrapping of URLs based on pattern, not link element
- Bugfix: Reference container: Backlink symbol: support for appending when combining identicals is on
- Bugfix: Reference container: Backlinks: deprioritize hover underline to ease customization
-- Bugfix: Footnote referrers: disable hover underline
-
-= 2.1.4d2 =
-- Bugfix: Styling: Referrers and backlinks: make link elements optional to fix issues
-- Update: Dashboard: Expert mode: streamline and update description for hooks and priority levels
-- Bugfix: Layout: Tooltip: prevent line break in Read-on link label
-
-= 2.1.4d1 =
-- Bugfix: Reference container, tooltips: fix line wrapping of URLs based on pattern, not link element
+- Bugfix: Reference container: Backlinks: fix line breaking with respect to separators and terminators
+- Bugfix: Reference container: Backlinks: options to disable separators and terminators
+- Bugfix: Reference container: Backlinks: optional line breaks to stack enumerations
+- Bugfix: Reference container: fix layout issues by moving backlink column width to settings
+- Bugfix: Reference container: Label: delete overflow hidden rule
+- Bugfix: Reference container: separating and terminating punctuation optional and customizable
- Bugfix: Reference container: Styles: re-add the class dedicated to combined footnotes indices
+- Bugfix: Styling: Referrers and backlinks: make link elements optional to fix issues
+- Bugfix: Styling: Referrers: disable hover underline
+- Bugfix: Styling: Tooltips: fix font size issue by moving it to settings, defaulting to inherit
+- Bugfix: WordPress hooks: the_content: set priority to 1000 as a safeguard
+- Update: Dashboard: Expert mode: streamline and update description for hooks and priority levels
= 2.1.3 =
- Bugfix: disable widget_text hook by default to fix accordions declaring headings as widgets
diff --git a/templates/dashboard/customize-css.html b/templates/dashboard/customize-css.html
index f85b1ae..dec8ae2 100644
--- a/templates/dashboard/customize-css.html
+++ b/templates/dashboard/customize-css.html
@@ -1,27 +1,27 @@
-
-
-
- [[label-css]] |
- [[css]] |
-
-
- [[headline]] |
-
-
- |
- [[label-class-1]] [[class-1]] |
-
-
- |
- [[label-class-2]] [[class-2]] |
-
-
- |
- [[label-class-3]] [[class-3]] |
-
-
- |
- [[label-class-4]] [[class-4]] |
-
-
+
+
+
+ [[label-css]] |
+ [[css]] |
+
+
+ [[headline]] |
+
+
+ |
+ [[label-class-1]] [[class-1]] |
+
+
+ |
+ [[label-class-2]] [[class-2]] |
+
+
+ |
+ [[label-class-3]] [[class-3]] |
+
+
+ |
+ [[label-class-4]] [[class-4]] |
+
+
diff --git a/templates/dashboard/customize-mouse-over-box.html b/templates/dashboard/customize-mouse-over-box.html
index 2b5a9d0..feab530 100644
--- a/templates/dashboard/customize-mouse-over-box.html
+++ b/templates/dashboard/customize-mouse-over-box.html
@@ -1,68 +1,68 @@
-
+
-
- [[label-enable]] |
- [[enable]] |
-
-
- [[label-alternative]] |
- [[alternative]] |
-
-
- [[label-activate-excerpt]] |
- [[activate-excerpt]] |
-
-
- [[label-excerpt-length]] |
- [[excerpt-length]] |
-
-
- [[label-readon]] |
- [[readon]] |
-
-
- [[label-position]] |
- [[position]] |
-
-
- [[label-offset-x]] |
- [[offset-x]] [[notice-offset-x]] |
-
-
- [[label-offset-y]] |
- [[offset-y]] [[notice-offset-y]] |
-
-
- [[label-max-width]] |
- [[max-width]] [[notice-max-width]] |
-
-
- [[label-font-size]] |
- [[font-size-enable]][[font-size-scalar]][[font-size-unit]] [[font-size-comment]] |
-
-
- [[label-color]] |
- [[color]] [[notice-color]] |
-
-
- [[label-background]] |
- [[background]] [[notice-background]] |
-
-
- [[label-border-width]] |
- [[border-width]] [[notice-border-width]] |
-
-
- [[label-border-color]] |
- [[border-color]] [[notice-border-color]] |
-
-
- [[label-border-radius]] |
- [[border-radius]] [[notice-border-radius]] |
-
-
- [[label-box-shadow-color]] |
- [[box-shadow-color]] [[notice-box-shadow-color]] |
-
+
+ [[label-enable]] |
+ [[enable]] |
+
+
+ [[label-alternative]] |
+ [[alternative]] |
+
+
+ [[label-activate-excerpt]] |
+ [[activate-excerpt]] |
+
+
+ [[label-excerpt-length]] |
+ [[excerpt-length]] |
+
+
+ [[label-readon]] |
+ [[readon]] |
+
+
+ [[label-position]] |
+ [[position]] |
+
+
+ [[label-offset-x]] |
+ [[offset-x]] [[notice-offset-x]] |
+
+
+ [[label-offset-y]] |
+ [[offset-y]] [[notice-offset-y]] |
+
+
+ [[label-max-width]] |
+ [[max-width]] [[notice-max-width]] |
+
+
+ [[label-font-size]] |
+ [[font-size-enable]][[font-size-scalar]][[font-size-unit]] [[font-size-comment]] |
+
+
+ [[label-color]] |
+ [[color]] [[notice-color]] |
+
+
+ [[label-background]] |
+ [[background]] [[notice-background]] |
+
+
+ [[label-border-width]] |
+ [[border-width]] [[notice-border-width]] |
+
+
+ [[label-border-color]] |
+ [[border-color]] [[notice-border-color]] |
+
+
+ [[label-border-radius]] |
+ [[border-radius]] [[notice-border-radius]] |
+
+
+ [[label-box-shadow-color]] |
+ [[box-shadow-color]] [[notice-box-shadow-color]] |
+
diff --git a/templates/dashboard/customize-superscript.html b/templates/dashboard/customize-superscript.html
index 12441fa..81e6770 100644
--- a/templates/dashboard/customize-superscript.html
+++ b/templates/dashboard/customize-superscript.html
@@ -1,16 +1,16 @@
-
-
-
- [[label-superscript]] |
- [[superscript]] |
-
-
- [[label-before]] |
- [[before]] |
-
-
- [[label-after]] |
- [[after]] |
-
-
+
+
+
+ [[label-superscript]] |
+ [[superscript]] |
+
+
+ [[label-before]] |
+ [[before]] |
+
+
+ [[label-after]] |
+ [[after]] |
+
+
diff --git a/templates/dashboard/diagnostics.html b/templates/dashboard/diagnostics.html
index 3452c82..bb9a428 100644
--- a/templates/dashboard/diagnostics.html
+++ b/templates/dashboard/diagnostics.html
@@ -1,37 +1,37 @@
-
-
-
- [[label-server]] |
- [[server]] |
-
-
- [[label-php]] |
- [[php]] |
-
-
- [[label-user-agent]] |
- [[user-agent]] |
-
-
- [[label-max-execution-time]] |
- [[max-execution-time]] |
-
-
- [[label-memory-limit]] |
- [[memory-limit]] |
-
-
- [[label-php-extensions]] |
- [[php-extensions]] |
-
-
- [[label-wordpress]] |
- [[wordpress]] |
-
-
- [[label-theme]] |
- [[theme]] |
-
- [[plugins]]
-
-
\ No newline at end of file
+
+
+
+ [[label-server]] |
+ [[server]] |
+
+
+ [[label-php]] |
+ [[php]] |
+
+
+ [[label-user-agent]] |
+ [[user-agent]] |
+
+
+ [[label-max-execution-time]] |
+ [[max-execution-time]] |
+
+
+ [[label-memory-limit]] |
+ [[memory-limit]] |
+
+
+ [[label-php-extensions]] |
+ [[php-extensions]] |
+
+
+ [[label-wordpress]] |
+ [[wordpress]] |
+
+
+ [[label-theme]] |
+ [[theme]] |
+
+ [[plugins]]
+
+
diff --git a/templates/dashboard/expert-lookup.html b/templates/dashboard/expert-lookup.html
index 71e4659..cea8679 100644
--- a/templates/dashboard/expert-lookup.html
+++ b/templates/dashboard/expert-lookup.html
@@ -5,43 +5,43 @@
-
- [[head-hook]] |
- [[head-checkbox]] |
- [[head-numbox]] |
- [[head-url]] |
-
+
+ [[head-hook]] |
+ [[head-checkbox]] |
+ [[head-numbox]] |
+ [[head-url]] |
+
-
- [[label-the-title]] |
- [[the-title]] |
- [[priority-the-title]] |
- [[url-the-title]] |
-
-
- [[label-the-content]] |
- [[the-content]] |
- [[priority-the-content]] |
- [[url-the-content]] |
-
-
- [[label-the-excerpt]] |
- [[the-excerpt]] |
- [[priority-the-excerpt]] |
- [[url-the-excerpt]] |
-
-
- [[label-widget-title]] |
- [[widget-title]] |
- [[priority-widget-title]] |
- [[url-widget-title]] |
-
-
- [[label-widget-text]] |
- [[widget-text]] |
- [[priority-widget-text]] |
- [[url-widget-text]] |
-
+
+ [[label-the-title]] |
+ [[the-title]] |
+ [[priority-the-title]] |
+ [[url-the-title]] |
+
+
+ [[label-the-content]] |
+ [[the-content]] |
+ [[priority-the-content]] |
+ [[url-the-content]] |
+
+
+ [[label-the-excerpt]] |
+ [[the-excerpt]] |
+ [[priority-the-excerpt]] |
+ [[url-the-excerpt]] |
+
+
+ [[label-widget-title]] |
+ [[widget-title]] |
+ [[priority-widget-title]] |
+ [[url-widget-title]] |
+
+
+ [[label-widget-text]] |
+ [[widget-text]] |
+ [[priority-widget-text]] |
+ [[url-widget-text]] |
+
diff --git a/templates/dashboard/settings-love.html b/templates/dashboard/settings-love.html
index 70dd4f2..cc34f8c 100644
--- a/templates/dashboard/settings-love.html
+++ b/templates/dashboard/settings-love.html
@@ -1,12 +1,12 @@
-
-
-
- [[label-love]] |
- [[love]] |
-
-
- [[label-no-love]] |
- [[no-love]] |
-
-
-
\ No newline at end of file
+
+
+
+ [[label-love]] |
+ [[love]] |
+
+
+ [[label-no-love]] |
+ [[no-love]] |
+
+
+
diff --git a/templates/dashboard/settings-other.html b/templates/dashboard/settings-other.html
index 97c5374..b141e47 100644
--- a/templates/dashboard/settings-other.html
+++ b/templates/dashboard/settings-other.html
@@ -1,17 +1,17 @@
-
- [[label-link]] |
- [[link]] |
-
-
- [[label-excerpt]] |
- [[excerpt]][[excerpt-comment1]] |
- [[excerpt-comment2]] [[excerpt-comment3]] |
-
-
- [[label-expert-mode]] |
- [[expert-mode]] |
-
+
+ [[label-link]] |
+ [[link]] |
+
+
+ [[label-excerpt]] |
+ [[excerpt]][[excerpt-comment1]] |
+ [[excerpt-comment2]] [[excerpt-comment3]] |
+
+
+ [[label-expert-mode]] |
+ [[expert-mode]] |
+
diff --git a/templates/dashboard/settings-reference-container.html b/templates/dashboard/settings-reference-container.html
index 0be44e7..4fdf822 100644
--- a/templates/dashboard/settings-reference-container.html
+++ b/templates/dashboard/settings-reference-container.html
@@ -1,78 +1,78 @@
-
+
-
- [[label-name]] |
- [[name]] |
-
-
- [[label-position]] |
- [[position]] |
-
-
- [[label-startpage]] |
- [[startpage]] |
-
-
- [[label-collapse]] |
- [[collapse]] |
-
-
- [[label-symbol]] |
-
- [[symbol-enable]]
- [[symbol-options]]
- [[symbol-custom]]
- [[symbol-comment]]
- |
-
-
- [[label-switch]] |
- [[switch]] |
-
-
- [[label-3column]] |
-
- [[3column]]
- [[3column-comment]]
- |
-
-
- [[label-separator]] |
-
- [[separator-enable]]
- [[separator-options]]
- [[separator-custom]]
- [[separator-comment]]
- |
-
-
- [[label-terminator]] |
-
- [[terminator-enable]]
- [[terminator-options]]
- [[terminator-custom]]
- [[terminator-comment]]
- |
-
-
- [[label-width]] |
-
- [[width-enable]]
- [[width-scalar]]
- [[width-unit]]
- |
-
-
- [[label-max-width]] |
-
- [[max-width-enable]]
- [[max-width-scalar]]
- [[max-width-unit]]
- |
-
-
- [[label-line-break]] |
- [[line-break]] |
-
+
+ [[label-name]] |
+ [[name]] |
+
+
+ [[label-position]] |
+ [[position]] |
+
+
+ [[label-startpage]] |
+ [[startpage]] |
+
+
+ [[label-collapse]] |
+ [[collapse]] |
+
+
+ [[label-symbol]] |
+
+ [[symbol-enable]]
+ [[symbol-options]]
+ [[symbol-custom]]
+ [[symbol-comment]]
+ |
+
+
+ [[label-switch]] |
+ [[switch]] |
+
+
+ [[label-3column]] |
+
+ [[3column]]
+ [[3column-comment]]
+ |
+
+
+ [[label-separator]] |
+
+ [[separator-enable]]
+ [[separator-options]]
+ [[separator-custom]]
+ [[separator-comment]]
+ |
+
+
+ [[label-terminator]] |
+
+ [[terminator-enable]]
+ [[terminator-options]]
+ [[terminator-custom]]
+ [[terminator-comment]]
+ |
+
+
+ [[label-width]] |
+
+ [[width-enable]]
+ [[width-scalar]]
+ [[width-unit]]
+ |
+
+
+ [[label-max-width]] |
+
+ [[max-width-enable]]
+ [[max-width-scalar]]
+ [[max-width-unit]]
+ |
+
+
+ [[label-line-break]] |
+ [[line-break]] |
+
diff --git a/templates/dashboard/settings-styling.html b/templates/dashboard/settings-styling.html
index 36e80a4..6920179 100644
--- a/templates/dashboard/settings-styling.html
+++ b/templates/dashboard/settings-styling.html
@@ -1,27 +1,27 @@
-
+
-
- [[label-short-code-start]] |
-
- [[short-code-start]]
- [[short-code-start-user]]
- |
-
-
- [[label-short-code-end]] |
-
- [[short-code-end]]
- [[short-code-end-user]]
- |
-
-
- [[label-counter-style]] |
- [[counter-style]] |
-
-
- [[label-identical]] |
- [[identical]] |
-
+
+ [[label-short-code-start]] |
+
+ [[short-code-start]]
+ [[short-code-start-user]]
+ |
+
+
+ [[label-short-code-end]] |
+
+ [[short-code-end]]
+ [[short-code-end-user]]
+ |
+
+
+ [[label-counter-style]] |
+ [[counter-style]] |
+
+
+ [[label-identical]] |
+ [[identical]] |
+
diff --git a/class/task.php b/class/task.php
index e328272..133634f 100644
--- a/class/task.php
+++ b/class/task.php
@@ -8,22 +8,23 @@
*
* Edited for v2.0.0 and following.
*
- * 2.0.5: Autoload / infinite scroll support added thanks to code from
+ * 2.0.5 Autoload / infinite scroll support added thanks to code from
* @docteurfitness
*
- * 2.0.9: DISABLED the_post HOOK 2020-11-08T1839+0100
- * 2.1.0: promoted the 'Continue reading' button from localization to customization 2020-11-08T2146+0100
- * 2.1.1: combining identical footnotes: fixed dead links 2020-11-14T2233+0100
- * 2.1.1: options fixing ref container layout and referrer vertical alignment 2020-11-16T2024+0100
- * 2.1.1: option fixing ref container relative position 2020-11-17T0254+0100
- * 2.1.2: options for the other hooks 2020-11-19T1849+0100
- * 2.1.4: fix line wrapping of URLs based on pattern, not link element 2020-11-25T0837+0100
- * 2.1.4: fix issues with link elements by making them optional 2020-11-26T1051+0100
- * 2.1.4: support appending arrow when combining identicals is on 2020-11-26T1633+0100
- * 2.1.4: disable or select backlink separator and terminator 2020-11-28T1048+0100
- * 2.1.4: optional line breaks to stack enumerated backlinks 2020-11-28T1049+0100
+ * 2.0.9 DISABLED the_post HOOK 2020-11-08T1839+0100
+ * 2.1.0 promoted the 'Continue reading' button from localization to customization 2020-11-08T2146+0100
+ * 2.1.1 combining identical footnotes: fixed dead links 2020-11-14T2233+0100
+ * 2.1.1 options fixing ref container layout and referrer vertical alignment 2020-11-16T2024+0100
+ * 2.1.1 option fixing ref container relative position 2020-11-17T0254+0100
+ * 2.1.2 options for the other hooks 2020-11-19T1849+0100
+ * 2.1.4 fix line wrapping of URLs based on pattern, not link element 2020-11-25T0837+0100
+ * 2.1.4 fix issues with link elements by making them optional 2020-11-26T1051+0100
+ * 2.1.4 support appending arrow when combining identicals is on 2020-11-26T1633+0100
+ * 2.1.4 disable or select backlink separator and terminator 2020-11-28T1048+0100
+ * 2.1.4 optional line breaks to stack enumerated backlinks 2020-11-28T1049+0100
+ * 2.1.4 ref container column width and tooltip font size settings 2020-12-03T0954+0100
*
- * Last modified: 2020-11-28T1049+0100
+ * Last modified: 2020-12-03T1623+0100
*/
// If called directly, abort:
@@ -165,9 +166,14 @@ class MCI_Footnotes_Task {
$l_str_BoxShadowColor = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_FOOTNOTES_MOUSE_OVER_BOX_SHADOW_COLOR);
// ref container first column width:
+ $l_bool_ColumnWidthEnabled = MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_BACKLINKS_COLUMN_WIDTH_ENABLED));
$l_int_ColumnWidthScalar = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_INT_BACKLINKS_COLUMN_WIDTH_SCALAR);
$l_str_ColumnWidthUnit = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_BACKLINKS_COLUMN_WIDTH_UNIT);
+ $l_bool_ColumnMaxWidthEnabled = MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_BACKLINKS_COLUMN_MAX_WIDTH_ENABLED));
+ $l_int_ColumnMaxWidthScalar = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_INT_BACKLINKS_COLUMN_MAX_WIDTH_SCALAR);
+ $l_str_ColumnMaxWidthUnit = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_BACKLINKS_COLUMN_MAX_WIDTH_UNIT);
+
if (!empty($l_int_ColumnWidthScalar)) {
if ($l_str_ColumnWidthUnit == '%') {
if ($l_int_ColumnWidthScalar > 100) {
@@ -178,10 +184,6 @@ class MCI_Footnotes_Task {
$l_int_ColumnWidthScalar = 0;
}
- // ref container first column max width:
- $l_int_ColumnMaxWidthScalar = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_INT_BACKLINKS_COLUMN_MAX_WIDTH_SCALAR);
- $l_str_ColumnMaxWidthUnit = MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_BACKLINKS_COLUMN_MAX_WIDTH_UNIT);
-
if (!empty($l_int_ColumnMaxWidthScalar)) {
if ($l_str_ColumnMaxWidthUnit == '%') {
if ($l_int_ColumnMaxWidthScalar > 100) {
@@ -201,20 +203,21 @@ class MCI_Footnotes_Task {
echo ".home .footnotes_reference_container { display: none; }\r\n";
}
- // first column width:
- if (MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_BACKLINKS_COLUMN_WIDTH_ENABLED))) {
+ // ref container first column width:
+ if ( $l_bool_ColumnWidthEnabled || $l_bool_ColumnMaxWidthEnabled ) {
+ echo ".footnote-reference-container { table-layout: fixed; }";
echo ".footnote_plugin_index, .footnote_plugin_index_combi {";
- echo " width: $l_int_ColumnWidthScalar$l_str_ColumnWidthUnit !important;";
- echo '}';
- }
-
- // first column max width:
- if (MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_BACKLINKS_COLUMN_MAX_WIDTH_ENABLED))) {
- echo ".footnote_plugin_index, .footnote_plugin_index_combi {";
- echo " max-width: $l_int_ColumnMaxWidthScalar$l_str_ColumnMaxWidthUnit !important;";
+
+ if ( $l_bool_ColumnWidthEnabled ) {
+ echo " width: $l_int_ColumnWidthScalar$l_str_ColumnWidthUnit !important;";
+ }
+ if ( $l_bool_ColumnMaxWidthEnabled ) {
+ echo " max-width: $l_int_ColumnMaxWidthScalar$l_str_ColumnMaxWidthUnit !important;";
+ }
echo '}';
}
+ // tooltip:
echo '.footnote_tooltip {';
echo ' font-size: ';
@@ -862,65 +865,64 @@ class MCI_Footnotes_Task {
$l_str_FootnoteBacklinks = $l_str_FootnoteReference;
$l_str_FootnoteBacklinks .= $l_str_BacklinkEvent;
- // finish both single note and notes cluster, depending on switch option status:
+ // continue both single note and notes cluster, depending on switch option status:
if ($l_bool_SymbolSwitch) {
- $l_str_FootnoteReference .= ">$l_str_FootnoteId$l_str_FootnoteArrow$l_str_LinkSpan>";
- $l_str_FootnoteBacklinks .= ">$l_str_FootnoteId$l_str_FootnoteArrow$l_str_LinkSpan>";
+ $l_str_FootnoteReference .= ">$l_str_FootnoteId$l_str_FootnoteArrow";
+ $l_str_FootnoteBacklinks .= ">$l_str_FootnoteId$l_str_FootnoteArrow";
} else {
- $l_str_FootnoteReference .= ">$l_str_FootnoteArrow$l_str_FootnoteId$l_str_LinkSpan>";
- $l_str_FootnoteBacklinks .= ">$l_str_FootnoteArrow$l_str_FootnoteId$l_str_LinkSpan>";
+ $l_str_FootnoteReference .= ">$l_str_FootnoteArrow$l_str_FootnoteId";
+ $l_str_FootnoteBacklinks .= ">$l_str_FootnoteArrow$l_str_FootnoteId";
}
- // If that is the only footnote with this text, we’re done.
-
- }
+ // If that is the only footnote with this text, we’re nearly done.
- // CHECK IF COMBINING IDENTICALS IS TURNED ON, and
- // check if it isn't the last footnote in the array:
- if ($l_int_FirstFootnoteIndex < count(self::$a_arr_Footnotes) && MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_COMBINE_IDENTICAL_FOOTNOTES))) {
+ // check if it isn't the last footnote in the array:
+ if ($l_int_FirstFootnoteIndex < count(self::$a_arr_Footnotes)) {
- // get all footnotes that haven't passed yet:
- for ($l_int_CheckIndex = $l_int_FirstFootnoteIndex; $l_int_CheckIndex < count(self::$a_arr_Footnotes); $l_int_CheckIndex++) {
+ // get all footnotes that haven't passed yet:
+ for ($l_int_CheckIndex = $l_int_FirstFootnoteIndex; $l_int_CheckIndex < count(self::$a_arr_Footnotes); $l_int_CheckIndex++) {
- // check if a further footnote is the same as the actual one:
- if ($l_str_FootnoteText == self::$a_arr_Footnotes[$l_int_CheckIndex]) {
+ // check if a further footnote is the same as the actual one:
+ if ($l_str_FootnoteText == self::$a_arr_Footnotes[$l_int_CheckIndex]) {
- // if so, set the further footnote as empty so it won't be displayed later:
- self::$a_arr_Footnotes[$l_int_CheckIndex] = "";
+ // if so, set the further footnote as empty so it won't be displayed later:
+ self::$a_arr_Footnotes[$l_int_CheckIndex] = "";
- // cancel the event altogether:
- $l_str_BacklinkEvent = "";
+ // cancel the event altogether:
+ $l_str_BacklinkEvent = "";
- // HERE GOES THE FRAGMENT IDENTIFIER AND THE BACKLINK TOO:
- // add the footnote index to the actual index:
+ // HERE GOES THE FRAGMENT IDENTIFIER AND THE BACKLINK TOO:
+ // add the footnote index to the actual index:
- // update the footnote ID:
- $l_str_FootnoteId = MCI_Footnotes_Convert::Index(($l_int_CheckIndex + 1), MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_FOOTNOTES_COUNTER_STYLE));
+ // update the footnote ID:
+ $l_str_FootnoteId = MCI_Footnotes_Convert::Index(($l_int_CheckIndex + 1), MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_FOOTNOTES_COUNTER_STYLE));
- // resume composing the backlinks enumeration:
- $l_str_FootnoteBacklinks .= "$l_str_Separator$l_str_LineBreak<$l_str_LinkSpan";
- $l_str_FootnoteBacklinks .= ' id="footnote_plugin_reference_';
- $l_str_FootnoteBacklinks .= $l_int_PostId;
- $l_str_FootnoteBacklinks .= "_$l_str_FootnoteId";
- $l_str_FootnoteBacklinks .= '" class="footnote_backlink" ';
- $l_str_FootnoteBacklinks .= 'onclick="footnote_moveToAnchor_' . $l_int_PostId;
- $l_str_FootnoteBacklinks .= "('footnote_plugin_tooltip_$l_int_PostId";
- $l_str_FootnoteBacklinks .= "_$l_str_FootnoteId');\">";
- $l_str_FootnoteBacklinks .= $l_bool_SymbolSwitch ? '' : $l_str_FootnoteArrow;
- $l_str_FootnoteBacklinks .= $l_str_FootnoteId;
- $l_str_FootnoteBacklinks .= $l_bool_SymbolSwitch ? $l_str_FootnoteArrow : '';
- $l_str_FootnoteBacklinks .= "$l_str_LinkSpan>";
-
- // this legacy is not used:
- //$l_str_FootnoteIndex .= ', ' . MCI_Footnotes_Convert::Index(($l_int_CheckIndex + 1), MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_STR_FOOTNOTES_COUNTER_STYLE));
+ // resume composing the backlinks enumeration:
+ $l_str_FootnoteBacklinks .= "$l_str_Separator$l_str_LinkSpan>";
+ $l_str_FootnoteBacklinks .= "$l_str_LineBreak<$l_str_LinkSpan";
+ $l_str_FootnoteBacklinks .= ' id="footnote_plugin_reference_';
+ $l_str_FootnoteBacklinks .= $l_int_PostId;
+ $l_str_FootnoteBacklinks .= "_$l_str_FootnoteId";
+ $l_str_FootnoteBacklinks .= '" class="footnote_backlink" ';
+ $l_str_FootnoteBacklinks .= 'onclick="footnote_moveToAnchor_' . $l_int_PostId;
+ $l_str_FootnoteBacklinks .= "('footnote_plugin_tooltip_$l_int_PostId";
+ $l_str_FootnoteBacklinks .= "_$l_str_FootnoteId');\">";
+ $l_str_FootnoteBacklinks .= $l_bool_SymbolSwitch ? '' : $l_str_FootnoteArrow;
+ $l_str_FootnoteBacklinks .= $l_str_FootnoteId;
+ $l_str_FootnoteBacklinks .= $l_bool_SymbolSwitch ? $l_str_FootnoteArrow : '';
+ }
}
}
+
+ $l_str_FootnoteReference .= "$l_str_Terminator$l_str_LinkSpan>";
+ $l_str_FootnoteBacklinks .= "$l_str_Terminator$l_str_LinkSpan>";
+
}
// line wrapping of URLs already fixed, see: